@@ -167,7 +167,7 @@ dialogSuffix(rows=7, columns=2, focus=nEntry)
 }
 
 
-Rcmdr.zsum <- function(){
+Rcmdr.distsum <- function(){
 initializeDialog(title=gettext("Evaluation of Objective Function for weighted sum Location Problem", domain="R-RcmdrPlugin.orloca"))
 xVar <- tclVar("0")
 xEntry <- tkentry(top, width="6", textvariable=xVar)
@@ -177,27 +177,27 @@ onOK <- function(){
 	closeDialog()
 	x <- as.numeric(tclvalue(xVar))
         if (is.na(x)){
-            errorCondition(recall=Rcmdr.zsum, message=gettext("x-axis must be a number.", domain="R-RcmdrPlugin.orloca"))
+            errorCondition(recall=Rcmdr.distsum, message=gettext("x-axis must be a number.", domain="R-RcmdrPlugin.orloca"))
             return()
             }
 	y <- as.numeric(tclvalue(yVar))
         if (is.na(y)){
-            errorCondition(recall=Rcmdr.zsum, message=gettext("y-axis must be a number.", domain="R-RcmdrPlugin.orloca"))
+            errorCondition(recall=Rcmdr.distsum, message=gettext("y-axis must be a number.", domain="R-RcmdrPlugin.orloca"))
             return()
             }
-        command <- paste("zsum(as(", ActiveDataSet(), ", \"loca.p\") , x = ", x,", y = ", y, sep="")
+        command <- paste("distsum(as(", ActiveDataSet(), ", \"loca.p\") , x = ", x,", y = ", y, sep="")
         command <- paste(command, .RcmdrPlugin.orloca.get.norma(), sep="")
         command <- paste(command, ") \n# ", sep="")
         command <- paste(command, gettext("Weighted sum of distances", domain="R-RcmdrPlugin.orloca"), sep="")
 	doItAndPrint(command)
-        command <- paste("zsumgra(as(", ActiveDataSet(), ", \"loca.p\") , x = ", x,", y = ", y, sep="")
+        command <- paste("distsumgra(as(", ActiveDataSet(), ", \"loca.p\") , x = ", x,", y = ", y, sep="")
         command <- paste(command, .RcmdrPlugin.orloca.get.norma(), sep="")
         command <- paste(command, ") # ", sep="")
         command <- paste(command, gettext("Gradient of the weighted sum of distances function", domain="R-RcmdrPlugin.orloca"), sep="")
 	doItAndPrint(command)
 	tkfocus(CommanderWindow())
 	}
-OKCancelHelp(helpSubject="zsum")
+OKCancelHelp(helpSubject="distsum")
 tkgrid(tklabel(top, text=gettext("x-axis", domain="R-RcmdrPlugin.orloca")), xEntry, sticky="e")
 tkgrid(tklabel(top, text=gettext("y-axis", domain="R-RcmdrPlugin.orloca")), yEntry, sticky="e")
 tkgrid(buttonsFrame, sticky="w", columnspan=2)
@@ -206,7 +206,7 @@ tkgrid.configure(yEntry, sticky="w")
 dialogSuffix(rows=2, columns=2, focus=xEntry)
 }
 
-Rcmdr.zsummin <- function(){
+Rcmdr.distsummin <- function(){
 initializeDialog(title=gettext("Solve weighted sum Location Problem", domain="R-RcmdrPlugin.orloca"))
 xVar <- tclVar("0")
 xEntry <- tkentry(top, width="6", textvariable=xVar)
@@ -218,44 +218,44 @@ epsVar <- tclVar("0.001")
 epsEntry <- tkentry(top, width="6", textvariable=epsVar)
 gettext("Gradient", domain="R-RcmdrPlugin.orloca")
 gettext("Search method", domain="R-RcmdrPlugin.orloca")
-radioButtons(name="algorithm", buttons=c("w", "g", "s", "u"), values=c("w", "g", "s", "u"), initialValue="w", labels=gettext(c("Weiszfeld", "Gradient", "Search method", "ucminf"), domain="R-RcmdrPlugin.orloca"), title=gettext("Select algorithm", domain="R-RcmdrPlugin.orloca"))
+radioButtons(name="algorithm", buttons=c("Weiszfeld", "gradient", "ucminf", "NelderMead", "BFGS", "CG", "LBFGSB", "SANN"), values=c("Weiszfeld", "gradient", "ucminf", "Nelder-Mead", "BFGS", "CG", "L-BFGS-B", "SANN"), initialValue="Weiszfeld", labels=gettext(c("Weiszfeld", "gradient", "ucminf", "Nelder-Mead", "BFGS", "CG", "L-BFGS-B", "SANN"), domain="R-RcmdrPlugin.orloca"), title=gettext("Select algorithm", domain="R-RcmdrPlugin.orloca"))
 
 #tkgrid(labelRcmdr(statisticFrame), sticky="w")
 onOK <- function(){
 	closeDialog()
 	x <- as.numeric(tclvalue(xVar))
         if (is.na(x)){
-            errorCondition(recall=Rcmdr.zsummin, message=gettext("x-axis must be a number.", domain="R-RcmdrPlugin.orloca"))
+            errorCondition(recall=Rcmdr.distsummin, message=gettext("x-axis must be a number.", domain="R-RcmdrPlugin.orloca"))
             return()
             }
 	y <- as.numeric(tclvalue(yVar))
         if (is.na(y)){
-            errorCondition(recall=Rcmdr.zsummin, message=gettext("y-axis must be a number.", domain="R-RcmdrPlugin.orloca"))
+            errorCondition(recall=Rcmdr.distsummin, message=gettext("y-axis must be a number.", domain="R-RcmdrPlugin.orloca"))
             return()
             }
 	n <- as.numeric(tclvalue(nVar))
         if (is.na(n) || n <= 0){
-            errorCondition(recall=Rcmdr.zsummin, message=gettext("The maximum number of iterations must be a positive integer", domain="R-RcmdrPlugin.orloca"))
+            errorCondition(recall=Rcmdr.distsummin, message=gettext("The maximum number of iterations must be a positive integer", domain="R-RcmdrPlugin.orloca"))
             return()
             }
 	eps <- as.numeric(tclvalue(epsVar))
         if (is.na(eps) || eps <= 0){
-            errorCondition(recall=Rcmdr.zsummin, message=gettext("The norm of the gradient must be positive.", domain="R-RcmdrPlugin.orloca"))
+            errorCondition(recall=Rcmdr.distsummin, message=gettext("The norm of the gradient must be positive.", domain="R-RcmdrPlugin.orloca"))
             return()
             }
         algorithm <- tclvalue(algorithmVariable)
-        command <- paste(".sol <- zsummin(as(", ActiveDataSet(), ", \"loca.p\") , x = ", x,", y = ", y,", eps =", eps, ", algorithm =\"", algorithm, "\"", sep="")
+        command <- paste(".sol <- distsummin(as(", ActiveDataSet(), ", \"loca.p\") , x = ", x,", y = ", y,", eps =", eps, ", algorithm =\"", algorithm, "\"", sep="")
         command <- paste(command, .RcmdrPlugin.orloca.get.norma(), " ) # ", gettext("Solve the minsum location problem", domain="R-RcmdrPlugin.orloca"), sep="")
 	doItAndPrint(command)
         doItAndPrint(paste(".sol #", gettext("Show the solution", domain="R-RcmdrPlugin.orloca")))
-        command <- paste("zsum(as(", ActiveDataSet(), ", \"loca.p\") , x =", .sol[1], ", y = ", .sol[2], wep="")
+        command <- paste("distsum(as(", ActiveDataSet(), ", \"loca.p\") , x =", .sol[1], ", y = ", .sol[2], wep="")
         command <- paste(command, .RcmdrPlugin.orloca.get.norma(), sep="")
         command <- paste(command, ") # ", gettext("Weighted sum of distances", domain="R-RcmdrPlugin.orloca"), sep="")
         doItAndPrint(command)
         doItAndPrint("remove(.sol)")
 	tkfocus(CommanderWindow())
 	}
-OKCancelHelp(helpSubject="zsummin")
+OKCancelHelp(helpSubject="distsummin")
 tkgrid(tklabel(top, text=gettext("Maximum number of iterations", domain="R-RcmdrPlugin.orloca")), nEntry, sticky="w")
 tkgrid.configure(nEntry, sticky="e")
 tkgrid(tklabel(top, text=gettext("x-axis", domain="R-RcmdrPlugin.orloca")), xEntry, sticky="w")
@@ -272,7 +272,6 @@ dialogSuffix(rows=20, columns=2, focus=xEntry)
 }
 
 
-
 Rcmdr.help.orloca <- function(){
    # To ensure that menu name is included in pot file
    gettext("Help about orloca", domain="R-RcmdrPlugin.orloca")
@@ -282,6 +281,16 @@ Rcmdr.help.orloca <- function(){
    invisible(NULL)
 }
 
+Rcmdr.help.orloca.vignettes <- function(){
+   # To ensure that menu name is included in pot file
+   gettext("Planar Location with orloca", domain="R-RcmdrPlugin.orloca")
+   command <- paste("vignette(\"", gettext("planarlocation", domain="R-RcmdrPlugin.orloca"), sep="")
+   command <- paste(command, "\")", sep="")
+   doItAndPrint(command)
+   invisible(NULL)
+}
+
+
 Rcmdr.help.RcmdrPlugin.orloca <- function(){
    # To ensure that menu name is included in pot file
    gettext("Help about RcmdrPlugin.orloca", domain="R-RcmdrPlugin.orloca")
@@ -291,6 +300,16 @@ Rcmdr.help.RcmdrPlugin.orloca <- function(){
    invisible(NULL)
 }
 
+Rcmdr.help.RcmdrPlugin.orloca.vignettes <- function(){
+   # To ensure that menu name is included in pot file
+   gettext("Planar Location with Rcmdr", domain="R-RcmdrPlugin.orloca")
+   command <- paste("vignette(\"", gettext("planarlocationRcmdr", domain="R-RcmdrPlugin.orloca"), sep="")
+   command <- paste(command, "\")", sep="")
+   doItAndPrint(command)
+   invisible(NULL)
+}
+
+
 Rcmdr.summary.loca.p <- function(){
    # To ensure that menu name is included in pot file
    gettext("Summary", domain="R-RcmdrPlugin.orloca")
@@ -348,7 +367,7 @@ onOK <- function(){
             }
         return()
 	}
-OKCancelHelp(helpSubject="zsum")
+OKCancelHelp(helpSubject="distsum")
 tkgrid(normaFrame, sticky="w")
 tkgrid(tklabel(top, text=gettext("p = ", domain="R-RcmdrPlugin.orloca")), nameEntry, sticky="e")
 tkgrid(buttonsFrame, sticky="w", columnspan=2)
